translate.storage.project

Package translate :: Package storage :: Module project |
[hide private]
[frames] | no frames]

# Module project

source code

Classes | [hide private]
| Project Manages a project store as well as the processes involved in a project workflow.

Functions | [hide private]
split_extensions(filename) Split the given filename into a name and extensions part. | source code

Variables | [hide private]
| __package__ = ``'``translate.storage``'``

Imports: os, convert_factory, ProjectStore

Function Details | [hide private]

### split_extensions(filename) | source code
Split the given filename into a name and extensions part. The extensions part is defined by any sequence of extensions, where an extension is a 3-letter, .-separated string or one of "po" or "properties". If the file name consists entirely out of extensions, the first part is assumed to be the file name and the rest extensions.